# Daily Brief — {YYYY-MM-DD}

**Generated by**: Mini-Mao

## Active Work

| Ticket | Agent | State | Notes |
|--------|-------|-------|-------|
| {ID} | {agent} | {state} | {brief} |

## Blocked

| Ticket | Agent | Blocked On | Since |
|--------|-------|------------|-------|
| {ID} | {agent} | {what} | {date} |

## Pending Architect Review

| Ticket | PR | Submitted |
|--------|-----|-----------|
| {ID} | #{N} | {date} |

## Stale Handoffs (>24h)

| Handoff | Age | Waiting For |
|---------|-----|-------------|
| {none or details} | | |

## Decisions Captured

{HDRs drafted since last brief, or "none"}

## Recommendations

{What Mini-Mao thinks the Architect should look at first — presented as options, not decisions}
